@@ -19,52 +19,52 @@ def test_render_empty():
 
 def test_render_str_val():
     inp = Cp2kInput({"FOO": "bar"})
-    assert inp.render() == "{inp.DISCLAIMER}\nFOO bar".format(inp=inp)
+    assert inp.render() == f"{inp.DISCLAIMER}\nFOO bar"
 
 
 def test_add_keyword():
     """Test  add_keyword()"""
     inp = Cp2kInput({"FOO": "bar"})
     inp.add_keyword("BAR", "boo")
-    assert inp.render() == "{inp.DISCLAIMER}\nBAR boo\nFOO bar".format(inp=inp)
+    assert inp.render() == f"{inp.DISCLAIMER}\nBAR boo\nFOO bar"
 
     inp.add_keyword("BOO/BAZ", "boo")
-    assert inp.render() == """{inp.DISCLAIMER}
+    assert inp.render() == f"""{inp.DISCLAIMER}
 BAR boo
 &BOO
    BAZ boo
 &END BOO
-FOO bar""".format(inp=inp)
+FOO bar"""
 
     inp.add_keyword(["BOO", "BII"], "boo")
-    assert inp.render() == """{inp.DISCLAIMER}
+    assert inp.render() == f"""{inp.DISCLAIMER}
 BAR boo
 &BOO
    BAZ boo
    BII boo
 &END BOO
-FOO bar""".format(inp=inp)
+FOO bar"""
 
     inp.add_keyword("BOO/BII", "bzzzzzz", override=False)
-    assert inp.render() == """{inp.DISCLAIMER}
+    assert inp.render() == f"""{inp.DISCLAIMER}
 BAR boo
 &BOO
    BAZ boo
    BII boo
 &END BOO
-FOO bar""".format(inp=inp)
+FOO bar"""
 
     inp.add_keyword("BOO/BII/BCC", "bcr", override=False)
-    assert inp.render() == """{inp.DISCLAIMER}
+    assert inp.render() == f"""{inp.DISCLAIMER}
 BAR boo
 &BOO
    BAZ boo
    BII boo
 &END BOO
-FOO bar""".format(inp=inp)
+FOO bar"""
 
     inp.add_keyword("BOO/BII/BCC", "bcr")
-    assert inp.render() == """{inp.DISCLAIMER}
+    assert inp.render() == f"""{inp.DISCLAIMER}
 BAR boo
 &BOO
    BAZ boo
@@ -72,10 +72,10 @@ BAR boo
       BCC bcr
    &END BII
 &END BOO
-FOO bar""".format(inp=inp)
+FOO bar"""
 
     inp.add_keyword("BOO/BII", "boo", override=False)
-    assert inp.render() == """{inp.DISCLAIMER}
+    assert inp.render() == f"""{inp.DISCLAIMER}
 BAR boo
 &BOO
    BAZ boo
@@ -83,53 +83,53 @@ BAR boo
       BCC bcr
    &END BII
 &END BOO
-FOO bar""".format(inp=inp)
+FOO bar"""
 
     inp.add_keyword("BOO/BII", "boo", override=True)
-    assert inp.render() == """{inp.DISCLAIMER}
+    assert inp.render() == f"""{inp.DISCLAIMER}
 BAR boo
 &BOO
    BAZ boo
    BII boo
 &END BOO
-FOO bar""".format(inp=inp)
+FOO bar"""
 
     inp.add_keyword("BOO/BII", "boo", override=True)
-    assert inp.render() == """{inp.DISCLAIMER}
+    assert inp.render() == f"""{inp.DISCLAIMER}
 BAR boo
 &BOO
    BAZ boo
    BII boo
 &END BOO
-FOO bar""".format(inp=inp)
+FOO bar"""
 
     inp.add_keyword("BOO/BIP", "bzz", override=False, conflicting_keys=['BII'])
-    assert inp.render() == """{inp.DISCLAIMER}
+    assert inp.render() == f"""{inp.DISCLAIMER}
 BAR boo
 &BOO
    BAZ boo
    BII boo
 &END BOO
-FOO bar""".format(inp=inp)
+FOO bar"""
 
     inp.add_keyword("BOO/BIP", "bzz", override=False, conflicting_keys=[])
-    assert inp.render() == """{inp.DISCLAIMER}
+    assert inp.render() == f"""{inp.DISCLAIMER}
 BAR boo
 &BOO
    BAZ boo
    BII boo
    BIP bzz
 &END BOO
-FOO bar""".format(inp=inp)
+FOO bar"""
 
     inp.add_keyword("BOO/BEE", "bee", override=True, conflicting_keys=['BAZ', 'BII'])
-    assert inp.render() == """{inp.DISCLAIMER}
+    assert inp.render() == f"""{inp.DISCLAIMER}
 BAR boo
 &BOO
    BEE bee
    BIP bzz
 &END BOO
-FOO bar""".format(inp=inp)
+FOO bar"""
 
 
 def test_add_keyword_invariant_inp():
@@ -137,13 +137,13 @@ def test_add_keyword_invariant_inp():
     param = {"FOO": "bar"}
     inp = Cp2kInput(param)
     inp.add_keyword("BAR", "boo")
-    assert inp.render() == "{inp.DISCLAIMER}\nBAR boo\nFOO bar".format(inp=inp)
+    assert inp.render() == f"{inp.DISCLAIMER}\nBAR boo\nFOO bar"
     assert param == {"FOO": "bar"}
 
 
 def test_multiple_force_eval():
     inp = Cp2kInput({"FORCE_EVAL": [{"FOO": "bar"}, {"FOO": "bar"}, {"FOO": "bar"}]})
-    assert inp.render() == """{inp.DISCLAIMER}
+    assert inp.render() == f"""{inp.DISCLAIMER}
 &FORCE_EVAL
    FOO bar
 &END FORCE_EVAL
@@ -152,16 +152,16 @@ def test_multiple_force_eval():
 &END FORCE_EVAL
 &FORCE_EVAL
    FOO bar
-&END FORCE_EVAL""".format(inp=inp)
+&END FORCE_EVAL"""
 
 
 def test_kinds():
     inp = Cp2kInput({"KIND": [{"_": "H"}, {"_": "O"}]})
-    assert inp.render() == """{inp.DISCLAIMER}
+    assert inp.render() == f"""{inp.DISCLAIMER}
 &KIND H
 &END KIND
 &KIND O
-&END KIND""".format(inp=inp)
+&END KIND"""
 
 
 def test_invariant_under_render():
